# HISTORY

## 0.4.1

* Added decorator support, `@anonymous_allowed` and `@authentication_required`
* Added back in test suite
* Updated typings and fixed a bug with instantiating `JWT` component

## 0.4.0 ** BREAKING CHANGE **

Apistar JWT updated to support Apistar >= 0.4. Pin to 0.3.3 for Apistar 0.3.x support

## 0.3.3

Update dev deps so we are using metadata 2.1 spec for pypi.

## 0.3.2

Updates to pin dependencies for Apistar 0.3.x and add Markdown rendering to pypi.org

## 0.3.1

Release for Apistar 0.3.x
